@@ -1,9 +1,8 @@
-from __future__ import annotations
 from abc import ABC, abstractmethod
 
 
 class StyleComponent(ABC):
-    def accept(self, visitor: Visitor):
+    def accept(self, visitor):
         visitor.visit(self)
 
     def apply(self) -> None:
@@ -12,7 +11,7 @@ class StyleComponent(ABC):
 
 class Visitor(ABC):
     @abstractmethod
-    def visit(self, element: StyleComponent) -> None:
+    def visit(self, element) -> None:
         pass
 
 
